summaryrefslogtreecommitdiff
path: root/Debian/Dgit.pm
diff options
context:
space:
mode:
Diffstat (limited to 'Debian/Dgit.pm')
-rw-r--r--Debian/Dgit.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/Debian/Dgit.pm b/Debian/Dgit.pm
index 8ed8364..3ac042c 100644
--- a/Debian/Dgit.pm
+++ b/Debian/Dgit.pm
@@ -1055,7 +1055,7 @@ sub playtree_setup () {
# $maindir_gitdir contains our main working "dgit", HEAD, etc.
# $maindir_gitcommon the shared stuff, including .objects
# we need to invoke git-playtree-create via git because
# there may be config options it needs which are only available
# to us, sensibly, in @git
@@ -1066,7 +1066,7 @@ sub playtree_setup () {
# @INC is conveniently available.
my $newpath = join ':', +(grep { !m/:/ } @INC),
'/usr/share/dgit', $ENV{PATH};
- runcmd qw(env), "PATH=$newpath", @git, qw(playtree-create .);
+ runcmd qw(env), "PATH=$newpath", @git, qw(playtree-setup .);
ensuredir '.git/info';
open GA, "> .git/info/attributes" or confess "$!";
@@ -1055,7 +1055,7 @@ sub playtree_setup () {
# $maindir_gitdir contains our main working "dgit", HEAD, etc.
# $maindir_gitcommon the shared stuff, including .objects
- # we need to invoke git-playtree-create via git because
+ # we need to invoke git-playtree-setup via git because
# there may be config options it needs which are only available
# to us, sensibly, in @git